from abaqusGui import *
import os
from saveFieldIcon import saveFieldIconData
from saveUserDefinedFieldsDB import SaveUserDefinedFieldsDB

absPath = os.path.abspath(__file__)
absDir  = os.path.dirname(absPath)
helpUrl = os.path.join(absDir, 'saveUserFields-help.htm')

description = \
            "This function adds any user defined field outputs generated in\n"\
            "the session step to the odb associated with the field output.\n"\
            "This plug-in's files may be copied from " + absDir


###########################################################################
# Class definition
###########################################################################

class SaveUserDefinedFieldsForm(AFXForm):

    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    def __init__(self, owner):
        
        AFXForm.__init__(self, owner)

        self.cmd = AFXGuiCommand(mode=self, method='saveToOdb',
            objectName='saveUserFields', registerQuery=False)
        
    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    def getFirstDialog(self):

        return SaveUserDefinedFieldsDB(self)
        

###########################################################################
# Register commands
###########################################################################

majorNumber, minorNumber, updateNumber = getAFXApp().getBaseVersionNumbers()
curVersion = '%s.%s-%s' %(majorNumber, minorNumber, updateNumber)
supportedVersion = '6.5-1'
version = '1.1-2'

if not curVersion[:3] < supportedVersion[:3]:
    toolset=getAFXApp().getAFXMainWindow().getPluginToolset()
    
    # Register a kernel plug-in in a menu.
    #
    toolset.registerGuiMenuButton(
        object=SaveUserDefinedFieldsForm(toolset),
        buttonText='Visualization|Save User Defined Fields...',
        icon=None,
        kernelInitString='import saveUserFields',
        applicableModules=["Visualization"],
        version=version,
        author='ABAQUS, Inc.',
        description=description,
        helpUrl=helpUrl)
        
    # Register a kernel plug-in in a toolbox.
    #
    toolset.registerGuiToolButton(
        toolboxName='Tools', 
        object=SaveUserDefinedFieldsForm(toolset),
        buttonText='\tSave User\nFields to\nODB',
        icon=FXXPMIcon(getAFXApp(), saveFieldIconData),
        kernelInitString='import saveUserFields',
        version=version,
        author='Dassault Systemes Simulia Corp.',
        description=description,
        applicableModules = ["Visualization"],
        helpUrl=helpUrl)
else:
    mainWindow = getAFXApp().getAFXMainWindow()
    mainWindow.writeToMessageArea('\nThe saveUserFields plug-in is not supported '
                                  'for versions older than %s\n'
                                  %supportedVersion)
