"""
  Note:
  This script is provided as an example of the scripting interface and
  is for demonstration purposes only

  The program is not an official product of ABAQUS Inc
  and has not been through any formal
  Quality Assurance procedure.

  Neither ABAQUS Inc nor ABAQUS UK Ltd can accept liability for
  any consequences or damages which may result from the use
  of this routine.

 Purpose:
     Save frames written to the temporary Session State Step to the currentOdb

 Limitations:
     Output database must be opened not "Read Only"

================================================================="""
from abaqus import session
from abaqusConstants import *
from visualization import OdbType

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
def saveToOdb():

    vp = session.viewports[session.currentViewportName]

    # Check odb is being displayed.
    #
    if type(vp.displayedObject) != OdbType:
        raise ValueError, ('There is no output database (ODB) '
                           'associated with the current viewport.\n\n'
                          'Select an ODB from the context bar, '
                          'or use "File->Open" to open an ODB.')

    odbName = vp.odbDisplay.name
    currentOdb = session.odbs[odbName]

    # Check odb is read only.
    #
    if currentOdb.isReadOnly:
        raise ValueError, ('The current output database (ODB) has been opened as read only.  '
                          'To add data to this ODB, uncheck the "Read Only" button '
                          'in the "Open Database" dialog.\n\n'
                          'Note: any current user defined fields will have to be '
                          'regenerated when the ODB has been re-opened.')

    # Check if scratchOdb has been created.
    #
    if not session.scratchOdbs.has_key(odbName):
        raise ValueError, ('No user field output found in '
                           'current output database (ODB).\n\n'
                           'Please create user field output first.')

    # Check if Session Step exists
    #
    if not session.scratchOdbs[odbName].steps.has_key('Session Step'):
        raise ValueError, ('No user field output found in '
                           'current output database (ODB).\n\n'
                           'Please create user field output first.')

    scratchOdb = session.scratchOdbs[odbName]
    tempFrames = scratchOdb.steps['Session Step'].frames

    # Create the user defined step if any frames need to be saved
    #
    if 'userFieldsStep' not in currentOdb.steps.keys():
        procedure = [currentOdb.steps[key].procedure
                         for key in currentOdb.steps.keys()
                         if '*DYNAMIC, EXPLICIT' in currentOdb.steps[key].procedure]
        if not procedure:
            procedure = ''
        else:
            procedure = procedure[0]
        ss = currentOdb.Step(name='userFieldsStep',
                             description='Step for user defined Fields',
                             domain=MODAL,
                             procedure=procedure) # modal so no confusion with real times
        init_des = tempFrames[0].description

        ss.Frame(mode=1, frequency=0.0, description=init_des)
    else:
        ss = currentOdb.steps['userFieldsStep']

    counter = 0
    for f in tempFrames:
        if counter > 0:
            new_des = f.description
            sf = ss.Frame(mode=1, frequency=0.0, description=new_des)
        else:
            sf = ss.frames[0]
        for name, fo in f.fieldOutputs.items():
            if name in sf.fieldOutputs.keys():
                print 'Field output "' + name + '" already'\
                      ' exists and cannot be overwritten'
            else:
                sf.FieldOutput(name=name, field=fo)
                print 'Field output "' + name + '" has been saved to the ODB.'
        counter += 1
    currentOdb.save()
